@@ -28,6 +28,10 @@
 
 #include "realloc.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 struct nettle_buffer
 {
   uint8_t *contents;
@@ -87,4 +91,8 @@ int
 nettle_buffer_copy(struct nettle_buffer *dst,
 		   const struct nettle_buffer *src);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* NETTLE_BUFFER_H_INCLUDED */
