@@ -30,6 +30,10 @@
 #include <stdarg.h>
 #include <stdlib.h>
 
+/* For errno and strerror */
+#include <errno.h>
+#include <string.h>
+
 #include "io.h"
 
 #define RANDOM_DEVICE "/dev/urandom"
@@ -37,6 +41,19 @@
 
 int quiet_flag = 0;
 
+void *
+xalloc(size_t size)
+{
+  void *p = malloc(size);
+  if (!p)
+    {
+      fprintf(stderr, "Virtual memory exhausted.\n");
+      abort();
+    }
+
+  return p;
+}
+
 void
 werror(const char *format, ...)
 {
@@ -61,8 +78,10 @@ read_file(const char *name, unsigned max_size, char **contents)
     
   f = fopen(name, "rb");
   if (!f)
-    return 0;
-
+    {
+      werror("Opening `%s' failed: %s\n", name, strerror(errno));
+      return 0;
+    }
   buffer = NULL;
 
   if (max_size && max_size < 100)
@@ -166,24 +185,3 @@ hash_file(const struct nettle_hash *hash, void *ctx, FILE *f)
 	return 1;
     }
 }
-
-#if WITH_PUBLIC_KEY
-int
-read_rsa_key(const char *name,
-	     struct rsa_public_key *pub,
-	     struct rsa_private_key *priv)
-{
-  unsigned length;
-  char *buffer;
-  int res;
-  
-  length = read_file(name, 0, &buffer);
-  if (!length)
-    return 0;
-
-  res = rsa_keypair_from_sexp(pub, priv, 0, length, buffer);
-  free(buffer);
-
-  return res;
-}
-#endif /* WITH_PUBLIC_KEY */
