@@ -36,15 +36,11 @@
 
 #include <time.h>
 
-/* For getopt */
-#if HAVE_UNISTD_H
-# include <unistd.h>
-#endif
-
 #include "aes.h"
 #include "arcfour.h"
 #include "blowfish.h"
 #include "cast128.h"
+#include "cbc.h"
 #include "des.h"
 #include "serpent.h"
 #include "twofish.h"
@@ -52,7 +48,7 @@
 #include "nettle-meta.h"
 #include "nettle-internal.h"
 
-#include "cbc.h"
+#include "getopt.h"
 
 static double frequency = 0.0;
 
@@ -90,7 +86,7 @@ time_function(void (*f)(void *arg), void *arg)
 struct bench_hash_info
 {
   void *ctx;
-  nettle_hash_update_func update;
+  nettle_hash_update_func *update;
   const uint8_t *data;
 };
 
@@ -104,7 +100,7 @@ bench_hash(void *arg)
 struct bench_cipher_info
 {
   void *ctx;
-  nettle_crypt_func crypt;
+  nettle_crypt_func *crypt;
   uint8_t *data;
 };
 
@@ -118,7 +114,7 @@ bench_cipher(void *arg)
 struct bench_cbc_info
 {
   void *ctx;
-  nettle_crypt_func crypt;
+  nettle_crypt_func *crypt;
  
   uint8_t *data;
   
@@ -310,7 +306,7 @@ time_cipher(const struct nettle_cipher *cipher)
 #endif
 
 int
-main(int argc UNUSED, char **argv UNUSED)
+main(int argc, char **argv)
 {
   unsigned i;
   int c;
