@@ -35,13 +35,10 @@
  * fix maximum size, and abort if we ever need anything larger. */
 
 #if HAVE_ALLOCA
-# define TMP_DECL(name, type, max) \
-type *name
-# define TMP_ALLOC(name, size) \
-(name = alloca(sizeof (*name) * size))
+# define TMP_DECL(name, type, max) type *name
+# define TMP_ALLOC(name, size) (name = alloca(sizeof (*name) * size))
 #else /* !HAVE_ALLOCA */
-# define TMP_DECL(name, type, max) \
-type name[max]
+# define TMP_DECL(name, type, max) type name[max]
 # define TMP_ALLOC(name, size) \
 do { if (size > (sizeof(name) / sizeof(name[0]))) abort(); } while (0)
 #endif 
@@ -51,7 +48,8 @@ do { if (size > (sizeof(name) / sizeof(name[0]))) abort(); } while (0)
 #define NETTLE_MAX_HASH_BLOCK_SIZE 64
 #define NETTLE_MAX_HASH_DIGEST_SIZE 32
 #define NETTLE_MAX_SEXP_ASSOC 17
- 
+#define NETTLE_MAX_CIPHER_BLOCK_SIZE 32
+
 /* Doesn't quite fit with the other algorithms, because of the weak
  * keys. Weak keys are not reported, the functions will simply crash
  * if you try to use a weak key. */
@@ -65,8 +63,15 @@ extern const struct nettle_cipher nettle_blowfish128;
  * code is not included in the nettle library, as that would make the
  * shared library depend on openssl. Instead, look at
  * examples/nettle-openssl.c. */
+extern const struct nettle_cipher nettle_openssl_aes128;
+extern const struct nettle_cipher nettle_openssl_aes192;
+extern const struct nettle_cipher nettle_openssl_aes256;
+extern const struct nettle_cipher nettle_openssl_arcfour128;
 extern const struct nettle_cipher nettle_openssl_blowfish128;
 extern const struct nettle_cipher nettle_openssl_des;
 extern const struct nettle_cipher nettle_openssl_cast128;
 
+extern const struct nettle_hash nettle_openssl_md5;
+extern const struct nettle_hash nettle_openssl_sha1;
+
 #endif /* NETTLE_INTERNAL_H_INCLUDED */
