@@ -11,8 +11,6 @@ progress(void *ctx UNUSED, int c)
 int
 test_main(void)
 {
-#if WITH_PUBLIC_KEY
-
   struct dsa_public_key pub;
   struct dsa_private_key key;
   
@@ -25,7 +23,7 @@ test_main(void)
   knuth_lfib_init(&lfib, 13);
 
   if (!dsa_generate_keypair(&pub, &key,
-			    &lfib, (nettle_random_func) knuth_lfib_random,
+			    &lfib, (nettle_random_func *) knuth_lfib_random,
 			    NULL, verbose ? progress : NULL,
 			    1024))
     FAIL();
@@ -37,8 +35,4 @@ test_main(void)
   dsa_private_key_clear(&key);
   
   SUCCESS();
-  
-#else /* !WITH_PUBLIC_KEY */
-  SKIP();
-#endif /* !WITH_PUBLIC_KEY */
 }
