@@ -1,14 +1,10 @@
 #include "testutils.h"
 
-#if WITH_PUBLIC_KEY
-# include "pkcs1.h"
-#endif
+#include "pkcs1.h"
 
 int
 test_main(void)
 {
-#if WITH_PUBLIC_KEY
-  
   uint8_t buffer[16];
   uint8_t expected[16] = {    1, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
 			   0xff, 0xff, 0xff, 0xff, 0,    'a',  'b',  'c' };
@@ -19,7 +15,4 @@ test_main(void)
   ASSERT(MEMEQ(sizeof(buffer), buffer, expected));
 
   SUCCESS();
-#else /* !WITH_PUBLIC_KEY */
-  SKIP();
-#endif /* !WITH_PUBLIC_KEY */
 }
