@@ -11,8 +11,6 @@ progress(void *ctx UNUSED, int c)
 int
 test_main(void)
 {
-#if WITH_PUBLIC_KEY
-
   struct rsa_public_key pub;
   struct rsa_private_key key;
   
@@ -29,7 +27,7 @@ test_main(void)
   knuth_lfib_init(&lfib, 13);
 
   if (!rsa_generate_keypair(&pub, &key,
-			    &lfib, (nettle_random_func) knuth_lfib_random,
+			    &lfib, (nettle_random_func *) knuth_lfib_random,
 			    NULL, verbose ? progress : NULL,
 			    1024, 50))
     FAIL();
@@ -51,7 +49,7 @@ test_main(void)
 
   mpz_set_ui(pub.e, 17);
   if (!rsa_generate_keypair(&pub, &key,
-			    &lfib, (nettle_random_func) knuth_lfib_random,
+			    &lfib, (nettle_random_func *) knuth_lfib_random,
 			    NULL, verbose ? progress : NULL,
 			    2000, 0))
     FAIL();
@@ -78,8 +76,4 @@ test_main(void)
   mpz_clear(expected);
 
   SUCCESS();
-  
-#else /* !WITH_PUBLIC_KEY */
-  SKIP();
-#endif /* !WITH_PUBLIC_KEY */
 }
